@@ -107,6 +107,7 @@ class UserInteraction(object):
         
         Note: Not console based implementations will want to overwrite this. """
         if question is not None: 
+	    sleep(0.01)
             return raw_input(_(question) + " ")
     
     def diag(self, data, localize=True, autoscroll=False, *args, **kwds):
@@ -187,6 +188,13 @@ class Char(ews_char, UserInteraction, Dialogs):
         for i in data.split("\n"): 
             self.diag(self.name + ': ' + i, localize=False)
     
+    def ask(self, data, localize=False, *args, **kwds): 
+        """Say something -> Show that the char says it."""
+        data = _(data)
+        for i in data.split("\n")[:-1]: 
+            self.diag(self.name + ': ' + i, localize=localize, *args, **kwds)
+        return super(Char, self).ask(self.name + ': ' + data.split("\n")[-1], *args, **kwds)
+    
     def act(self, data): 
         """Do something -> Show that the char does it in the style "<name> walks away.".
         
@@ -501,7 +509,7 @@ class Story(UserInteraction, Dialogs):
             for i in chars:
                     i.save()
     
-    def give_exp(self, char, amount=0): 
+    def give_exp(self, char, amount=0, *args, **kwds): 
         """Give experience to only one char."""
         for i in self.get_experience([char], amount=amount).splitlines(): 
             self.diag(i)
